summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--kdict/Makefile.am2
-rw-r--r--kdict/queryview.cpp4
-rw-r--r--kdict/queryview.h2
-rw-r--r--kget/kget_plug_in/Makefile.am2
-rw-r--r--kget/kget_plug_in/kget_plug_in.cpp8
-rw-r--r--kopete/kopete/chatwindow/chatmessagepart.cpp14
-rw-r--r--kopete/kopete/chatwindow/chatmessagepart.h4
-rw-r--r--kopete/kopete/chatwindow/chatview.cpp2
-rw-r--r--kopete/kopete/config/appearance/appearanceconfig.cpp2
-rw-r--r--kopete/libkopete/tests/mock/Makefile.am2
-rw-r--r--kopete/libkopete/ui/Makefile.am2
-rw-r--r--kopete/libkopete/ui/userinfodialog.cpp4
-rw-r--r--kopete/libkopete/ui/userinfodialog.h2
-rw-r--r--kopete/plugins/history/Makefile.am4
-rw-r--r--kopete/plugins/history/historydialog.cpp2
-rw-r--r--kopete/plugins/history/historydialog.h8
-rw-r--r--kopete/plugins/statistics/Makefile.am2
-rw-r--r--kopete/plugins/statistics/statisticsdialog.cpp2
-rw-r--r--kopete/plugins/statistics/statisticsdialog.h4
-rw-r--r--kopete/protocols/irc/Makefile.am2
-rw-r--r--lanbrowsing/tdeio_lan/AUTHORS (renamed from lanbrowsing/kio_lan/AUTHORS)0
-rw-r--r--lanbrowsing/tdeio_lan/CMakeLists.txt (renamed from lanbrowsing/kio_lan/CMakeLists.txt)0
-rw-r--r--lanbrowsing/tdeio_lan/Makefile.am (renamed from lanbrowsing/kio_lan/Makefile.am)0
-rw-r--r--lanbrowsing/tdeio_lan/README (renamed from lanbrowsing/kio_lan/README)0
-rw-r--r--lanbrowsing/tdeio_lan/TODO (renamed from lanbrowsing/kio_lan/TODO)0
-rw-r--r--lanbrowsing/tdeio_lan/lan.desktop (renamed from lanbrowsing/kio_lan/lan.desktop)0
-rw-r--r--lanbrowsing/tdeio_lan/lan.protocol (renamed from lanbrowsing/kio_lan/lan.protocol)0
-rw-r--r--lanbrowsing/tdeio_lan/lisa.desktop (renamed from lanbrowsing/kio_lan/lisa.desktop)0
-rw-r--r--lanbrowsing/tdeio_lan/rlan.protocol (renamed from lanbrowsing/kio_lan/rlan.protocol)0
-rw-r--r--lanbrowsing/tdeio_lan/tdeio_lan.cpp (renamed from lanbrowsing/kio_lan/kio_lan.cpp)0
-rw-r--r--lanbrowsing/tdeio_lan/tdeio_lan.h (renamed from lanbrowsing/kio_lan/kio_lan.h)0
31 files changed, 37 insertions, 37 deletions
diff --git a/kdict/Makefile.am b/kdict/Makefile.am
index d9e600f6..a65f1a7e 100644
--- a/kdict/Makefile.am
+++ b/kdict/Makefile.am
@@ -12,7 +12,7 @@ tdeinit_LTLIBRARIES = kdict.la
AM_CPPFLAGS = $(all_includes)
kdict_la_LDFLAGS = $(KDE_RPATH) $(all_libraries) -module $(KDE_PLUGIN)
-kdict_la_LIBADD = $(LIB_KFILE) $(LIB_KHTML) $(LIBPTHREAD) $(LIBRESOLV)
+kdict_la_LIBADD = $(LIB_KFILE) $(LIB_TDEHTML) $(LIBPTHREAD) $(LIBRESOLV)
kdict_la_SOURCES = dcopinterface.skel main.cpp actions.cpp dict.cpp options.cpp \
queryview.cpp toplevel.cpp sets.cpp matchview.cpp application.cpp
diff --git a/kdict/queryview.cpp b/kdict/queryview.cpp
index 88dc69de..7dbeaba4 100644
--- a/kdict/queryview.cpp
+++ b/kdict/queryview.cpp
@@ -110,7 +110,7 @@ BrowseData::BrowseData(const TQString &Nhtml, const TQString &NqueryText)
//********* DictHTMLPart ******************************************
DictHTMLPart::DictHTMLPart(TQWidget *parentWidget, const char *widgetname)
- : KHTMLPart(parentWidget,widgetname)
+ : TDEHTMLPart(parentWidget,widgetname)
{}
@@ -123,7 +123,7 @@ void DictHTMLPart::tdehtmlMouseReleaseEvent(tdehtml::MouseReleaseEvent *event)
if (event->qmouseEvent()->button()==Qt::MidButton)
emit(middleButtonClicked());
else
- KHTMLPart::tdehtmlMouseReleaseEvent(event);
+ TDEHTMLPart::tdehtmlMouseReleaseEvent(event);
}
diff --git a/kdict/queryview.h b/kdict/queryview.h
index ddce43de..359eac85 100644
--- a/kdict/queryview.h
+++ b/kdict/queryview.h
@@ -74,7 +74,7 @@ public:
//********* DictHTMLPart ***************************************
-class DictHTMLPart : public KHTMLPart
+class DictHTMLPart : public TDEHTMLPart
{
Q_OBJECT
diff --git a/kget/kget_plug_in/Makefile.am b/kget/kget_plug_in/Makefile.am
index d067473d..cff33984 100644
--- a/kget/kget_plug_in/Makefile.am
+++ b/kget/kget_plug_in/Makefile.am
@@ -4,7 +4,7 @@ kde_module_LTLIBRARIES = tdehtml_kget.la
tdehtml_kget_la_METASOURCES = AUTO
tdehtml_kget_la_SOURCES = kget_plug_in.cpp kget_linkview.cpp links.cpp
-tdehtml_kget_la_LIBADD = $(LIB_KHTML)
+tdehtml_kget_la_LIBADD = $(LIB_TDEHTML)
tdehtml_kget_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN) -module $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor $(LIB_KPARTS)
KDE_ICON = AUTO
diff --git a/kget/kget_plug_in/kget_plug_in.cpp b/kget/kget_plug_in/kget_plug_in.cpp
index edb90655..c8e5ccf2 100644
--- a/kget/kget_plug_in/kget_plug_in.cpp
+++ b/kget/kget_plug_in/kget_plug_in.cpp
@@ -104,16 +104,16 @@ void KGet_plug_in::slotShowDrop()
void KGet_plug_in::slotShowLinks()
{
- if ( !parent() || !parent()->inherits( "KHTMLPart" ) )
+ if ( !parent() || !parent()->inherits( "TDEHTMLPart" ) )
return;
- KHTMLPart *htmlPart = static_cast<KHTMLPart*>( parent() );
+ TDEHTMLPart *htmlPart = static_cast<TDEHTMLPart*>( parent() );
KParts::Part *activePart = 0L;
if ( htmlPart->partManager() )
{
activePart = htmlPart->partManager()->activePart();
- if ( activePart && activePart->inherits( "KHTMLPart" ) )
- htmlPart = static_cast<KHTMLPart*>( activePart );
+ if ( activePart && activePart->inherits( "TDEHTMLPart" ) )
+ htmlPart = static_cast<TDEHTMLPart*>( activePart );
}
DOM::HTMLDocument doc = htmlPart->htmlDocument();
diff --git a/kopete/kopete/chatwindow/chatview.cpp b/kopete/kopete/chatwindow/chatview.cpp
index 136a9b4e..487f80c5 100644
--- a/kopete/kopete/chatwindow/chatview.cpp
+++ b/kopete/kopete/chatwindow/chatview.cpp
@@ -88,7 +88,7 @@ ChatView::ChatView( Kopete::ChatSession *mgr, ChatWindowPlugin *parent, const ch
//FIXME: don't widgets start off hidden anyway?
hide();
- //Create the view dock widget (KHTML Part), and set it to no docking (lock it in place)
+ //Create the view dock widget (TDEHTML Part), and set it to no docking (lock it in place)
viewDock = createDockWidget(TQString::fromLatin1( "viewDock" ), TQPixmap(),
0L,TQString::fromLatin1("viewDock"), TQString::fromLatin1(" "));
m_messagePart = new ChatMessagePart( mgr, viewDock, "m_messagePart" );
diff --git a/kopete/kopete/config/appearance/appearanceconfig.cpp b/kopete/kopete/config/appearance/appearanceconfig.cpp
index 0aff7691..56d5d3cf 100644
--- a/kopete/kopete/config/appearance/appearanceconfig.cpp
+++ b/kopete/kopete/config/appearance/appearanceconfig.cpp
@@ -238,7 +238,7 @@ AppearanceConfig::AppearanceConfig(TQWidget *parent, const char* /*name*/, const
d->preview->setJavaEnabled(false);
d->preview->setPluginsEnabled(false);
d->preview->setMetaRefreshEnabled(false);
- KHTMLView *htmlWidget = d->preview->view();
+ TDEHTMLView *htmlWidget = d->preview->view();
htmlWidget->setMarginWidth(4);
htmlWidget->setMarginHeight(4);
htmlWidget->setFocusPolicy(TQ_NoFocus);
diff --git a/kopete/libkopete/tests/mock/Makefile.am b/kopete/libkopete/tests/mock/Makefile.am
index b132a2a5..84b6dee7 100644
--- a/kopete/libkopete/tests/mock/Makefile.am
+++ b/kopete/libkopete/tests/mock/Makefile.am
@@ -7,7 +7,7 @@ noinst_LTLIBRARIES = libkopete_mock.la
libkopete_mock_la_SOURCES = kopetemessage_mock.cpp kopeteaccount_mock.cpp kopetecontact_mock.cpp kopetemetacontact_mock.cpp kopeteprotocol_mock.cpp
libkopete_mock_la_LDFLAGS = $(all_libraries) -lkabc
-libkopete_mock_la_LIBADD = ../../libkopete.la ../../private/libkopeteprivate.la $(LIB_KHTML)
+libkopete_mock_la_LIBADD = ../../libkopete.la ../../private/libkopeteprivate.la $(LIB_TDEHTML)
noinst_HEADERS = kopetemessage_mock.h kopetecontact_mock.h kopetemetacontact_mock.h kopeteaccount_mock.h kopeteprotocol_mock.h
diff --git a/kopete/libkopete/ui/Makefile.am b/kopete/libkopete/ui/Makefile.am
index bd7f3c21..3e88846d 100644
--- a/kopete/libkopete/ui/Makefile.am
+++ b/kopete/libkopete/ui/Makefile.am
@@ -15,7 +15,7 @@ libkopeteui_la_SOURCES = kopetecontactaction.cpp addcontactpage.cpp \
addressbooklinkwidget.cpp
libkopeteui_la_LDFLAGS = $(all_libraries) -lkabc
-libkopeteui_la_LIBADD = ../private/libkopeteprivate.la $(LIB_KHTML)
+libkopeteui_la_LIBADD = ../private/libkopeteprivate.la $(LIB_TDEHTML)
kopeteincludedir = $(includedir)/kopete/ui
kopeteinclude_HEADERS = accountselector.h fileconfirmbase.h \
diff --git a/kopete/libkopete/ui/userinfodialog.cpp b/kopete/libkopete/ui/userinfodialog.cpp
index 99c306f8..130973ce 100644
--- a/kopete/libkopete/ui/userinfodialog.cpp
+++ b/kopete/libkopete/ui/userinfodialog.cpp
@@ -45,7 +45,7 @@ struct UserInfoDialog::UserInfoDialogPrivate {
TQVBoxLayout *topLayout;
TQWidget *page;
DialogStyle style;
- KHTMLPart *htmlPart;
+ TDEHTMLPart *htmlPart;
KLineEdit *nameEdit;
KLineEdit *idEdit;
@@ -146,7 +146,7 @@ TQHBox* UserInfoDialog::addLabelEdit( const TQString& label, const TQString& tex
void UserInfoDialog::fillHTML()
{
- d->htmlPart = new KHTMLPart( this );
+ d->htmlPart = new TDEHTMLPart( this );
TQString text;
/*
diff --git a/kopete/libkopete/ui/userinfodialog.h b/kopete/libkopete/ui/userinfodialog.h
index 511aeb3f..9a7bcb4e 100644
--- a/kopete/libkopete/ui/userinfodialog.h
+++ b/kopete/libkopete/ui/userinfodialog.h
@@ -38,7 +38,7 @@ namespace Kopete {
/**
* Specifies the look of this dialog. If set to HTML only
- * KHTMLPart will be in the dialog and it's look can be customized
+ * TDEHTMLPart will be in the dialog and it's look can be customized
* through setStyleSheet
* @see setStyleSheet
*/
diff --git a/kopete/plugins/history/Makefile.am b/kopete/plugins/history/Makefile.am
index b43b8ed4..c0066373 100644
--- a/kopete/plugins/history/Makefile.am
+++ b/kopete/plugins/history/Makefile.am
@@ -7,11 +7,11 @@ kde_module_LTLIBRARIES = kopete_history.la kcm_kopete_history.la
kopete_history_la_SOURCES = historyplugin.cpp historydialog.cpp historyviewer.ui\
historylogger.cpp converter.cpp historyguiclient.cpp historyconfig.kcfgc
-kopete_history_la_LDFLAGS = -module -no-undefined $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor $(LIB_KHTML) $(LIB_KUTILS)
+kopete_history_la_LDFLAGS = -module -no-undefined $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor $(LIB_TDEHTML) $(LIB_KUTILS)
kopete_history_la_LIBADD = ../../libkopete/libkopete.la
kcm_kopete_history_la_SOURCES = historyprefsui.ui historypreferences.cpp historyconfig.kcfgc
-kcm_kopete_history_la_LDFLAGS = -module -no-undefined $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor $(LIB_KHTML) $(LIB_KUTILS)
+kcm_kopete_history_la_LDFLAGS = -module -no-undefined $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor $(LIB_TDEHTML) $(LIB_KUTILS)
kcm_kopete_history_la_LIBADD = ../../libkopete/libkopete.la $(LIB_KUTILS)
service_DATA = kopete_history.desktop
diff --git a/kopete/plugins/history/historydialog.cpp b/kopete/plugins/history/historydialog.cpp
index 708b85fc..1dd63cc3 100644
--- a/kopete/plugins/history/historydialog.cpp
+++ b/kopete/plugins/history/historydialog.cpp
@@ -135,7 +135,7 @@ HistoryDialog::HistoryDialog(Kopete::MetaContact *mc, TQWidget* parent,
// Initializing HTML Part
mMainWidget->htmlFrame->setFrameStyle(TQFrame::WinPanel | TQFrame::Sunken);
TQVBoxLayout *l = new TQVBoxLayout(mMainWidget->htmlFrame);
- mHtmlPart = new KHTMLPart(mMainWidget->htmlFrame, "htmlHistoryView");
+ mHtmlPart = new TDEHTMLPart(mMainWidget->htmlFrame, "htmlHistoryView");
//Security settings, we don't need this stuff
mHtmlPart->setJScriptEnabled(false);
diff --git a/kopete/plugins/history/historydialog.h b/kopete/plugins/history/historydialog.h
index 05295ad6..4df323d6 100644
--- a/kopete/plugins/history/historydialog.h
+++ b/kopete/plugins/history/historydialog.h
@@ -33,8 +33,8 @@ class HistoryViewer;
namespace Kopete { class MetaContact; }
namespace Kopete { class XSLT; }
class HistoryLogger;
-class KHTMLView;
-class KHTMLPart;
+class TDEHTMLView;
+class TDEHTMLPart;
class KURL;
namespace KParts { struct URLArgs; class Part; }
@@ -127,8 +127,8 @@ class HistoryDialog : public KDialogBase
TQPtrList<Kopete::MetaContact> mMetaContactList;
// History View
- KHTMLView *mHtmlView;
- KHTMLPart *mHtmlPart;
+ TDEHTMLView *mHtmlView;
+ TDEHTMLPart *mHtmlPart;
HistoryViewer *mMainWidget;
Kopete::XSLT *mXsltParser;
diff --git a/kopete/plugins/statistics/Makefile.am b/kopete/plugins/statistics/Makefile.am
index 93a8e28a..e7cb9c25 100644
--- a/kopete/plugins/statistics/Makefile.am
+++ b/kopete/plugins/statistics/Makefile.am
@@ -6,7 +6,7 @@ kde_module_LTLIBRARIES = kopete_statistics.la
kopete_statistics_la_SOURCES = statisticsplugin.cpp statisticsdb.cpp statisticsdialog.cpp statisticswidget.ui statisticscontact.cpp statisticsdcopiface.skel
-kopete_statistics_la_LDFLAGS = -module -no-undefined $(KDE_PLUGIN) $(all_libraries) -lsqlite3 $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor $(LIB_KHTML)
+kopete_statistics_la_LDFLAGS = -module -no-undefined $(KDE_PLUGIN) $(all_libraries) -lsqlite3 $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor $(LIB_TDEHTML)
kopete_statistics_la_LIBADD = ../../libkopete/libkopete.la -lsqlite3
service_DATA = kopete_statistics.desktop
diff --git a/kopete/plugins/statistics/statisticsdialog.cpp b/kopete/plugins/statistics/statisticsdialog.cpp
index ad7adb9e..02a5f4b7 100644
--- a/kopete/plugins/statistics/statisticsdialog.cpp
+++ b/kopete/plugins/statistics/statisticsdialog.cpp
@@ -53,7 +53,7 @@ StatisticsDialog::StatisticsDialog(StatisticsContact *contact, StatisticsDB *db,
TQHBox *hbox = new TQHBox(this);
- generalHTMLPart = new KHTMLPart(hbox);
+ generalHTMLPart = new TDEHTMLPart(hbox);
generalHTMLPart->setOnlyLocalReferences(true);
connect ( generalHTMLPart->browserExtension(), TQT_SIGNAL( openURLRequestDelayed( const KURL &, const KParts::URLArgs & ) ),
this, TQT_SLOT( slotOpenURLRequest( const KURL &, const KParts::URLArgs & ) ) );
diff --git a/kopete/plugins/statistics/statisticsdialog.h b/kopete/plugins/statistics/statisticsdialog.h
index def9d03e..a84f4b0e 100644
--- a/kopete/plugins/statistics/statisticsdialog.h
+++ b/kopete/plugins/statistics/statisticsdialog.h
@@ -29,7 +29,7 @@ class StatisticsPlugin;
class StatisticsDB;
class StatisticsContact;
-class KHTMLPart;
+class TDEHTMLPart;
class KURL;
namespace KParts
{
@@ -49,7 +49,7 @@ class StatisticsDialog : public KDialogBase
TQString stringFromSeconds(const int seconds);
StatisticsWidget *mainWidget;
- KHTMLPart *generalHTMLPart;
+ TDEHTMLPart *generalHTMLPart;
/// Database from which we get the statistics
StatisticsDB *m_db;
diff --git a/kopete/protocols/irc/Makefile.am b/kopete/protocols/irc/Makefile.am
index 37e27bad..93b5d46f 100644
--- a/kopete/protocols/irc/Makefile.am
+++ b/kopete/protocols/irc/Makefile.am
@@ -22,7 +22,7 @@ kopete_irc_la_SOURCES = \
kcodecaction.cpp \
ksparser.cpp
-kopete_irc_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor $(LIB_KHTML)
+kopete_irc_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor $(LIB_TDEHTML)
kopete_irc_la_LIBADD = ../../libkopete/libkopete.la \
./ui/libkopeteircui.la \
./libkirc/libkirc.la \
diff --git a/lanbrowsing/kio_lan/AUTHORS b/lanbrowsing/tdeio_lan/AUTHORS
index 062f9d6c..062f9d6c 100644
--- a/lanbrowsing/kio_lan/AUTHORS
+++ b/lanbrowsing/tdeio_lan/AUTHORS
diff --git a/lanbrowsing/kio_lan/CMakeLists.txt b/lanbrowsing/tdeio_lan/CMakeLists.txt
index 50794770..50794770 100644
--- a/lanbrowsing/kio_lan/CMakeLists.txt
+++ b/lanbrowsing/tdeio_lan/CMakeLists.txt
diff --git a/lanbrowsing/kio_lan/Makefile.am b/lanbrowsing/tdeio_lan/Makefile.am
index df87f09d..df87f09d 100644
--- a/lanbrowsing/kio_lan/Makefile.am
+++ b/lanbrowsing/tdeio_lan/Makefile.am
diff --git a/lanbrowsing/kio_lan/README b/lanbrowsing/tdeio_lan/README
index 224cae5b..224cae5b 100644
--- a/lanbrowsing/kio_lan/README
+++ b/lanbrowsing/tdeio_lan/README
diff --git a/lanbrowsing/kio_lan/TODO b/lanbrowsing/tdeio_lan/TODO
index 8640402e..8640402e 100644
--- a/lanbrowsing/kio_lan/TODO
+++ b/lanbrowsing/tdeio_lan/TODO
diff --git a/lanbrowsing/kio_lan/lan.desktop b/lanbrowsing/tdeio_lan/lan.desktop
index c5f1f59d..c5f1f59d 100644
--- a/lanbrowsing/kio_lan/lan.desktop
+++ b/lanbrowsing/tdeio_lan/lan.desktop
diff --git a/lanbrowsing/kio_lan/lan.protocol b/lanbrowsing/tdeio_lan/lan.protocol
index a4101a0e..a4101a0e 100644
--- a/lanbrowsing/kio_lan/lan.protocol
+++ b/lanbrowsing/tdeio_lan/lan.protocol
diff --git a/lanbrowsing/kio_lan/lisa.desktop b/lanbrowsing/tdeio_lan/lisa.desktop
index b4807d94..b4807d94 100644
--- a/lanbrowsing/kio_lan/lisa.desktop
+++ b/lanbrowsing/tdeio_lan/lisa.desktop
diff --git a/lanbrowsing/kio_lan/rlan.protocol b/lanbrowsing/tdeio_lan/rlan.protocol
index f41507e7..f41507e7 100644
--- a/lanbrowsing/kio_lan/rlan.protocol
+++ b/lanbrowsing/tdeio_lan/rlan.protocol
diff --git a/lanbrowsing/kio_lan/kio_lan.cpp b/lanbrowsing/tdeio_lan/tdeio_lan.cpp
index e573f7ea..e573f7ea 100644
--- a/lanbrowsing/kio_lan/kio_lan.cpp
+++ b/lanbrowsing/tdeio_lan/tdeio_lan.cpp
diff --git a/lanbrowsing/kio_lan/kio_lan.h b/lanbrowsing/tdeio_lan/tdeio_lan.h
index 6b9887dc..6b9887dc 100644
--- a/lanbrowsing/kio_lan/kio_lan.h
+++ b/lanbrowsing/tdeio_lan/tdeio_lan.h
diff --git a/kopete/kopete/chatwindow/chatmessagepart.cpp b/kopete/kopete/chatwindow/chatmessagepart.cpp
index 7a6235f1..8b7d5e3e 100644
--- a/kopete/kopete/chatwindow/chatmessagepart.cpp
+++ b/kopete/kopete/chatwindow/chatmessagepart.cpp
@@ -36,7 +36,7 @@
#include <tqtimer.h>
#include <tqstylesheet.h>
-// KHTML::DOM includes
+// TDEHTML::DOM includes
#include <dom/dom_doc.h>
#include <dom/dom_text.h>
#include <dom/dom_element.h>
@@ -214,7 +214,7 @@ private:
};
ChatMessagePart::ChatMessagePart( Kopete::ChatSession *mgr, TQWidget *parent, const char *name)
- : KHTMLPart( parent, name ), d( new Private )
+ : TDEHTMLPart( parent, name ), d( new Private )
{
d->manager = mgr;
@@ -228,7 +228,7 @@ ChatMessagePart::ChatMessagePart( Kopete::ChatSession *mgr, TQWidget *parent, co
setMetaRefreshEnabled( false );
setOnlyLocalReferences( true );
// Write the template to KHTMLPart
writeTemplate();
view()->setFocusPolicy( TQ_NoFocus );
@@ -834,7 +834,7 @@ void ChatMessagePart::copy(bool justselection /* default false */)
long startOffset, endOffset;
selection( startNode, startOffset, endNode, endOffset );
//BEGIN: copied from KHTMLPart::selectedText
bool hasNewLine = true;
DOM::Node n = startNode;
@@ -858,7 +858,7 @@ void ChatMessagePart::copy(bool justselection /* default false */)
unsigned short id = n.elementId();
switch(id)
{
- case ID_IMG: //here is the main difference with KHTMLView::selectedText
+ case ID_IMG: //here is the main difference with TDEHTMLView::selectedText
{
DOM::HTMLElement e = n;
if( !e.isNull() && e.hasAttribute( "title" ) )
@@ -936,7 +936,7 @@ void ChatMessagePart::copy(bool justselection /* default false */)
text=text.mid(start, end-start);
//END: copied from KHTMLPart::selectedText
#endif
if(text.isEmpty()) return;
@@ -974,7 +974,7 @@ void ChatMessagePart::print()
void ChatMessagePart::tdehtmlDrawContentsEvent( tdehtml::DrawContentsEvent * event) //virtual
{
- KHTMLPart::tdehtmlDrawContentsEvent(event);
+ TDEHTMLPart::tdehtmlDrawContentsEvent(event);
//copy(true /*selection only*/); not needed anymore.
}
void ChatMessagePart::slotCloseView( bool force )
@@ -228,7 +228,7 @@ ChatMessagePart::ChatMessagePart( Kopete::ChatSession *mgr, TQWidget *parent, co
setMetaRefreshEnabled( false );
setOnlyLocalReferences( true );
- // Write the template to KHTMLPart
+ // Write the template to TDEHTMLPart
writeTemplate();
view()->setFocusPolicy( TQ_NoFocus );
@@ -834,7 +834,7 @@ void ChatMessagePart::copy(bool justselection /* default false */)
long startOffset, endOffset;
selection( startNode, startOffset, endNode, endOffset );
- //BEGIN: copied from KHTMLPart::selectedText
+ //BEGIN: copied from TDEHTMLPart::selectedText
bool hasNewLine = true;
DOM::Node n = startNode;
@@ -936,7 +936,7 @@ void ChatMessagePart::copy(bool justselection /* default false */)
text=text.mid(start, end-start);
- //END: copied from KHTMLPart::selectedText
+ //END: copied from TDEHTMLPart::selectedText
#endif
if(text.isEmpty()) return;
diff --git a/kopete/kopete/chatwindow/chatmessagepart.h b/kopete/kopete/chatwindow/chatmessagepart.h
index 10eacd11..278291bb 100644
--- a/kopete/kopete/chatwindow/chatmessagepart.h
+++ b/kopete/kopete/chatwindow/chatmessagepart.h
@@ -36,7 +36,7 @@ class ChatWindowStyle;
/**
* @author Richard Smith
*/
-class ChatMessagePart : public KHTMLPart
+class ChatMessagePart : public TDEHTMLPart
{
Q_OBJECT
@@ -233,7 +233,7 @@ private:
TQString formatMessageBody( const Kopete::Message &message );
/**
* Write the template file to KHTMLPart
*/
void writeTemplate();
@@ -233,7 +233,7 @@ private:
TQString formatMessageBody( const Kopete::Message &message );
/**
- * Write the template file to KHTMLPart
+ * Write the template file to TDEHTMLPart
*/
void writeTemplate();